/*!
 * @license
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { EventEmitter, OnChanges, OnDestroy, OnInit, ElementRef, QueryList, ChangeDetectorRef, AfterViewInit } from '@angular/core';
import { TagService } from './services/tag.service';
import { TagEntry } from '@alfresco/js-api';
import { MatChip } from '@angular/material/chips';
import * as i0 from "@angular/core";
/**
 *
 * This component, ShowNodeTag a list of the tag on relative a node
 */
export declare class TagNodeListComponent implements OnChanges, OnDestroy, OnInit, AfterViewInit {
    private tagService;
    private changeDetectorRef;
    /** The identifier of a node. */
    nodeId: string;
    /** Show delete button */
    showDelete: boolean;
    /** Should limit number of tags displayed */
    limitTagsDisplayed: boolean;
    containerView: ElementRef;
    tagChips: QueryList<MatChip>;
    tagsEntries: TagEntry[];
    calculationsDone: boolean;
    columnFlexDirection: boolean;
    undisplayedTagsCount: number;
    viewMoreButtonLeftOffset: number;
    /** Emitted when a tag is selected. */
    results: EventEmitter<any>;
    private onDestroy$;
    private initialLimitTagsDisplayed;
    private initialTagsEntries;
    private viewMoreButtonLeftOffsetBeforeFlexDirection;
    private requestedDisplayingAllTags;
    private resizeObserver;
    constructor(tagService: TagService, changeDetectorRef: ChangeDetectorRef);
    ngOnChanges(): void;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    refreshTag(): void;
    removeTag(tag: string): void;
    displayAllTags(event: Event): void;
    private calculateTagsToDisplay;
    private getTagChipMargin;
    static ɵfac: i0.ɵɵFactoryDeclaration<TagNodeListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TagNodeListComponent, "adf-tag-node-list", never, { "nodeId": "nodeId"; "showDelete": "showDelete"; "limitTagsDisplayed": "limitTagsDisplayed"; }, { "results": "results"; }, never, never, false>;
}
